from setuptools import setup

setup(name='probability-distributions-dhan',
      version='0.1',
      description='Probability distributions',
      packages=['probability-distributions-dhan'],
      zip_safe=False)
